import unittest

from unittest.mock import MagicMock
from pyubibot import Ubibot

class TestStringMethods(unittest.TestCase):
    def setUp(self):
        self.ubibot = Ubibot("123abc")
        self.ubibot.get_channel = MagicMock(return_value={})
        self.ubibot.get_channels = MagicMock(return_value={})
    
    def test_get_channel(self):
        assert self.ubibot.get_channel() == {}
    
    def test_get_channels(self):
        assert self.ubibot.get_channels() == {}

if __name__ == '__main__':
    unittest.main()


import datetime
import unittest
import json
import os

from pyubibot import Channel


class TestStringMethods(unittest.TestCase):
    def setUp(self):
        with open(os.path.join(os.path.join(os.path.dirname(__file__),"testchannel.json"))) as json_file:
            self.channel = Channel(json.load(json_file), 1234)

    def test_get_field_name_by_sensor(self):
        self.assertEqual(self.channel.get_field_name_by_sensor("Temperature"), "field1")
        self.assertEqual(self.channel.get_field_name_by_sensor("Humidity"), "field2")
        self.assertEqual(self.channel.get_field_name_by_sensor("Light"), "field3")

    def test_get_last_value(self):
        self.assertTrue(self.channel.get_last_value() is not None)

    def test_get_last_value_by_field(self):
        self.assertEqual(self.channel.get_last_value_by_field("field1"), 35.806824)
        self.assertEqual(self.channel.get_last_value_by_field("field2"), 20)
        self.assertEqual(self.channel.get_last_value_by_field("field3"), 0)

    def test_get_last_updated_by_field(self):
        self.assertAlmostEqual(self.channel.get_last_updated_by_field("field1"),
                               datetime.datetime.strptime("2020-02-24T20:52:38Z", "%Y-%m-%dT%H:%M:%SZ"))
        self.assertAlmostEqual(self.channel.get_last_updated_by_field("field2"),
                               datetime.datetime.strptime("2020-02-24T20:52:38Z", "%Y-%m-%dT%H:%M:%SZ"))
        self.assertAlmostEqual(self.channel.get_last_updated_by_field("field3"),
                               datetime.datetime.strptime("2020-02-24T20:52:38Z", "%Y-%m-%dT%H:%M:%SZ"))


if __name__ == '__main__':
    unittest.main()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyubibot",
    version="0.0.3",
    author="Danny Tsang",
    author_email="danny@tsang.uk",
    description="Python implementation for Ubibot APIs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dannytsang/pyubibot",
    packages=setuptools.find_packages(where="pyubibot"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent"
    ],
    python_requires=">=3.8"
)